summaryrefslogtreecommitdiffstats
path: root/kbabel/kbabel/kbabel.h
diff options
context:
space:
mode:
Diffstat (limited to 'kbabel/kbabel/kbabel.h')
-rw-r--r--kbabel/kbabel/kbabel.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kbabel/kbabel/kbabel.h b/kbabel/kbabel/kbabel.h
index 5b38414d..b1b63122 100644
--- a/kbabel/kbabel/kbabel.h
+++ b/kbabel/kbabel/kbabel.h
@@ -139,14 +139,14 @@ protected:
* This function is called when it is time for the app to save its
* properties for session management purposes.
*/
- virtual void saveProperties(KConfig *);
+ virtual void saveProperties(TDEConfig *);
/**
* This function is called when this app is restored. The KConfig
* object points to the session management config file that was saved
* with @ref saveProperties
*/
- virtual void readProperties(KConfig *);
+ virtual void readProperties(TDEConfig *);
virtual bool queryExit();
virtual bool queryClose();
@@ -139,14 +139,14 @@ protected:
/**
- * This function is called when this app is restored. The KConfig
+ * This function is called when this app is restored. The TDEConfig
* object points to the session management config file that was saved
* with @ref saveProperties